@@ -7,7 +7,7 @@ use XML::Simple;
 use warnings;
 use strict;
 
-$VMware::API::vCloud::VERSION = '2.402';
+$VMware::API::vCloud::VERSION = '2.403';
 
 # ADMIN OPTS - http://www.vmware.com/support/vcd/doc/rest-api-doc-1.5-html/landing-admin_operations.html
 # USER OPTS - http://www.vmware.com/support/vcd/doc/rest-api-doc-1.5-html/landing-user_operations.html
@@ -226,7 +226,7 @@ sub _xml_response {
 sub _parse_xml {
   my $self = shift @_;
   my $xml  = shift @_;
-  my $data = XMLin( $xml, ForceArray => 1 );
+  my $data = XMLin( $xml, KeyAttr => [ qw(id) ], ForceArray => 1, );
   return $data;
 }
 
@@ -437,6 +437,9 @@ sub login {
   $self->{raw}->{login} = $self->_xml_response($response);
 
   for my $link ( @{$self->{raw}->{login}->{Link}} ) {
+	next 
+		unless defined $link->{type};
+
     $self->{learned}->{url}->{admin}         = $link->{href} if $link->{type} eq 'application/vnd.vmware.admin.vcloud+xml';
     $self->{learned}->{url}->{entity}        = $link->{href} if $link->{type} eq 'application/vnd.vmware.vcloud.entity+xml';
     $self->{learned}->{url}->{extensibility} = $link->{href} if $link->{type} eq 'application/vnd.vmware.vcloud.apiextensibility+xml';
@@ -1524,11 +1527,11 @@ dearly love a few changes, that might help things:
 
 =head1 VERSION
 
-	VMware::API::vCloud v2.402 (2014/03/12)
+	VMware::API::vCloud v2.403 (2023/09/13)
 
 =head1 COPYRIGHT
 
-	(c) 2011-2014, Phillip Pollard <bennie@cpan.org>
+	(c) 2011-2023, Phillip Pollard <bennie@cpan.org>
 
 =head1 LICENSE
 
