@@ -8,7 +8,7 @@ use VMware::vCloud::vApp;
 use warnings;
 use strict;
 
-$VMware::vCloud::VERSION = '2.402';
+$VMware::vCloud::VERSION = '2.403';
 
 =head1 NAME
 
@@ -532,10 +532,11 @@ sub list_orgs {
     $orgs = {};
     my $ret = $self->{api}->org_list();
 
-    for my $orgname ( keys %{$ret->{Org}} ) {
-      warn "Org type of $ret->{Org}->{$orgname}->{type} listed for $orgname\n" unless $ret->{Org}->{$orgname}->{type} eq 'application/vnd.vmware.vcloud.org+xml';
-      my $href = $ret->{Org}->{$orgname}->{href};
-      $orgs->{$orgname} = $href;
+    for my $org ( @{$ret->{Org}} ) {
+      warn "Org type of $org->{type} listed for $org->{name}\n" 
+        unless $org->{type} eq 'application/vnd.vmware.vcloud.org+xml';
+      my $href = $org->{href};
+      $orgs->{$org->{name}} = $href;
     }
     $cache->set('list_orgs:',$orgs); 
   }
@@ -647,7 +648,7 @@ that Organization.
 sub list_vdcs {
   my $self    = shift @_;
   my $orgname = shift @_;
-  $orgname = undef if $orgname eq 'System'; # Show all if the org is System
+  $orgname = '' if !defined $orgname || $orgname =~ /^[sS]ystem$/; # Show all if the org is System
   my $vdcs = our $cache->get("list_vdcs:$orgname:");
 
   unless ( defined $vdcs ) {
@@ -1067,11 +1068,11 @@ identifier of an object. This module implements this best practice.
 
 =head1 VERSION
 
-	VMware::vCloud v2.402 (2014/03/12)
+	VMware::vCloud v2.403 (2023/09/13)
 
 =head1 COPYRIGHT
 
-	(c) 2011-2014, Phillip Pollard <bennie@cpan.org>
+	(c) 2011-2023, Phillip Pollard <bennie@cpan.org>
 
 =head1 LICENSE
 
